# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Package(object):
    """
    Details of `Package` object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Package object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Package.
        :type id: str

        :param publisher_id:
            The value to assign to the publisher_id property of this Package.
        :type publisher_id: str

        :param name:
            The value to assign to the name property of this Package.
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this Package.
        :type display_name: str

        :param version:
            The value to assign to the version property of this Package.
        :type version: str

        :param time_uploaded:
            The value to assign to the time_uploaded property of this Package.
        :type time_uploaded: datetime

        :param time_published:
            The value to assign to the time_published property of this Package.
        :type time_published: datetime

        :param description:
            The value to assign to the description property of this Package.
        :type description: str

        :param resource_types:
            The value to assign to the resource_types property of this Package.
        :type resource_types: list[str]

        :param resource_types_metadata:
            The value to assign to the resource_types_metadata property of this Package.
        :type resource_types_metadata: list[oci.oda.models.ResourceTypeMetadata]

        :param publisher_metadata:
            The value to assign to the publisher_metadata property of this Package.
        :type publisher_metadata: list[oci.oda.models.MetadataProperty]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Package.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Package.
        :type defined_tags: dict(str, dict(str, object))

        :param import_contract:
            The value to assign to the import_contract property of this Package.
        :type import_contract: oci.oda.models.ImportContract

        :param default_parameter_values:
            The value to assign to the default_parameter_values property of this Package.
        :type default_parameter_values: oci.oda.models.DefaultParameterValues

        """
        self.swagger_types = {
            'id': 'str',
            'publisher_id': 'str',
            'name': 'str',
            'display_name': 'str',
            'version': 'str',
            'time_uploaded': 'datetime',
            'time_published': 'datetime',
            'description': 'str',
            'resource_types': 'list[str]',
            'resource_types_metadata': 'list[ResourceTypeMetadata]',
            'publisher_metadata': 'list[MetadataProperty]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'import_contract': 'ImportContract',
            'default_parameter_values': 'DefaultParameterValues'
        }

        self.attribute_map = {
            'id': 'id',
            'publisher_id': 'publisherId',
            'name': 'name',
            'display_name': 'displayName',
            'version': 'version',
            'time_uploaded': 'timeUploaded',
            'time_published': 'timePublished',
            'description': 'description',
            'resource_types': 'resourceTypes',
            'resource_types_metadata': 'resourceTypesMetadata',
            'publisher_metadata': 'publisherMetadata',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'import_contract': 'importContract',
            'default_parameter_values': 'defaultParameterValues'
        }

        self._id = None
        self._publisher_id = None
        self._name = None
        self._display_name = None
        self._version = None
        self._time_uploaded = None
        self._time_published = None
        self._description = None
        self._resource_types = None
        self._resource_types_metadata = None
        self._publisher_metadata = None
        self._freeform_tags = None
        self._defined_tags = None
        self._import_contract = None
        self._default_parameter_values = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Package.
        Unique immutable identifier that was assigned when the Package was registered.


        :return: The id of this Package.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Package.
        Unique immutable identifier that was assigned when the Package was registered.


        :param id: The id of this Package.
        :type: str
        """
        self._id = id

    @property
    def publisher_id(self):
        """
        **[Required]** Gets the publisher_id of this Package.
        ID of the publisher providing the package.


        :return: The publisher_id of this Package.
        :rtype: str
        """
        return self._publisher_id

    @publisher_id.setter
    def publisher_id(self, publisher_id):
        """
        Sets the publisher_id of this Package.
        ID of the publisher providing the package.


        :param publisher_id: The publisher_id of this Package.
        :type: str
        """
        self._publisher_id = publisher_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Package.
        Name of package.


        :return: The name of this Package.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Package.
        Name of package.


        :param name: The name of this Package.
        :type: str
        """
        self._name = name

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Package.
        Display name for the package (displayed in UI and user-facing applications).


        :return: The display_name of this Package.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Package.
        Display name for the package (displayed in UI and user-facing applications).


        :param display_name: The display_name of this Package.
        :type: str
        """
        self._display_name = display_name

    @property
    def version(self):
        """
        **[Required]** Gets the version of this Package.
        Version of the package.


        :return: The version of this Package.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Package.
        Version of the package.


        :param version: The version of this Package.
        :type: str
        """
        self._version = version

    @property
    def time_uploaded(self):
        """
        **[Required]** Gets the time_uploaded of this Package.
        When the package was uploaded. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_uploaded of this Package.
        :rtype: datetime
        """
        return self._time_uploaded

    @time_uploaded.setter
    def time_uploaded(self, time_uploaded):
        """
        Sets the time_uploaded of this Package.
        When the package was uploaded. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_uploaded: The time_uploaded of this Package.
        :type: datetime
        """
        self._time_uploaded = time_uploaded

    @property
    def time_published(self):
        """
        **[Required]** Gets the time_published of this Package.
        When the package was last published. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_published of this Package.
        :rtype: datetime
        """
        return self._time_published

    @time_published.setter
    def time_published(self, time_published):
        """
        Sets the time_published of this Package.
        When the package was last published. A date-time string as described in `RFC 3339`__, section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_published: The time_published of this Package.
        :type: datetime
        """
        self._time_published = time_published

    @property
    def description(self):
        """
        **[Required]** Gets the description of this Package.
        Description of the package.


        :return: The description of this Package.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Package.
        Description of the package.


        :param description: The description of this Package.
        :type: str
        """
        self._description = description

    @property
    def resource_types(self):
        """
        **[Required]** Gets the resource_types of this Package.
        A list of resource types describing the content of the package.


        :return: The resource_types of this Package.
        :rtype: list[str]
        """
        return self._resource_types

    @resource_types.setter
    def resource_types(self, resource_types):
        """
        Sets the resource_types of this Package.
        A list of resource types describing the content of the package.


        :param resource_types: The resource_types of this Package.
        :type: list[str]
        """
        self._resource_types = resource_types

    @property
    def resource_types_metadata(self):
        """
        **[Required]** Gets the resource_types_metadata of this Package.
        A map of resource type to metadata key/value map that further describes the content for the resource types in this package.. Keys are resource type names, values are a map of name/value pairs per resource type.


        :return: The resource_types_metadata of this Package.
        :rtype: list[oci.oda.models.ResourceTypeMetadata]
        """
        return self._resource_types_metadata

    @resource_types_metadata.setter
    def resource_types_metadata(self, resource_types_metadata):
        """
        Sets the resource_types_metadata of this Package.
        A map of resource type to metadata key/value map that further describes the content for the resource types in this package.. Keys are resource type names, values are a map of name/value pairs per resource type.


        :param resource_types_metadata: The resource_types_metadata of this Package.
        :type: list[oci.oda.models.ResourceTypeMetadata]
        """
        self._resource_types_metadata = resource_types_metadata

    @property
    def publisher_metadata(self):
        """
        **[Required]** Gets the publisher_metadata of this Package.
        A map of metadata key/value pairs that further describes the publisher and the platform in which the package might be used.


        :return: The publisher_metadata of this Package.
        :rtype: list[oci.oda.models.MetadataProperty]
        """
        return self._publisher_metadata

    @publisher_metadata.setter
    def publisher_metadata(self, publisher_metadata):
        """
        Sets the publisher_metadata of this Package.
        A map of metadata key/value pairs that further describes the publisher and the platform in which the package might be used.


        :param publisher_metadata: The publisher_metadata of this Package.
        :type: list[oci.oda.models.MetadataProperty]
        """
        self._publisher_metadata = publisher_metadata

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Package.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Package.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Package.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Package.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Package.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Package.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Package.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Package.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def import_contract(self):
        """
        **[Required]** Gets the import_contract of this Package.

        :return: The import_contract of this Package.
        :rtype: oci.oda.models.ImportContract
        """
        return self._import_contract

    @import_contract.setter
    def import_contract(self, import_contract):
        """
        Sets the import_contract of this Package.

        :param import_contract: The import_contract of this Package.
        :type: oci.oda.models.ImportContract
        """
        self._import_contract = import_contract

    @property
    def default_parameter_values(self):
        """
        **[Required]** Gets the default_parameter_values of this Package.

        :return: The default_parameter_values of this Package.
        :rtype: oci.oda.models.DefaultParameterValues
        """
        return self._default_parameter_values

    @default_parameter_values.setter
    def default_parameter_values(self, default_parameter_values):
        """
        Sets the default_parameter_values of this Package.

        :param default_parameter_values: The default_parameter_values of this Package.
        :type: oci.oda.models.DefaultParameterValues
        """
        self._default_parameter_values = default_parameter_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RemoveVcnIpv6CidrDetails(object):
    """
    Details used when removing ULA or private IPv6 prefix or an IPv6 GUA assigned by Oracle or BYOIPv6 prefix. You can only remove one of these per request.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RemoveVcnIpv6CidrDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ipv6_cidr_block:
            The value to assign to the ipv6_cidr_block property of this RemoveVcnIpv6CidrDetails.
        :type ipv6_cidr_block: str

        """
        self.swagger_types = {
            'ipv6_cidr_block': 'str'
        }

        self.attribute_map = {
            'ipv6_cidr_block': 'ipv6CidrBlock'
        }

        self._ipv6_cidr_block = None

    @property
    def ipv6_cidr_block(self):
        """
        Gets the ipv6_cidr_block of this RemoveVcnIpv6CidrDetails.
        This field is not required and should only be specified when removing ULA or private IPv6 prefix or an IPv6 GUA assigned by Oracle or BYOIPv6 prefix
        from a VCN's IPv6 address space.
        See`IPv6 Addresses`__.

        Example: `2001:0db8:0123::/56`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :return: The ipv6_cidr_block of this RemoveVcnIpv6CidrDetails.
        :rtype: str
        """
        return self._ipv6_cidr_block

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, ipv6_cidr_block):
        """
        Sets the ipv6_cidr_block of this RemoveVcnIpv6CidrDetails.
        This field is not required and should only be specified when removing ULA or private IPv6 prefix or an IPv6 GUA assigned by Oracle or BYOIPv6 prefix
        from a VCN's IPv6 address space.
        See`IPv6 Addresses`__.

        Example: `2001:0db8:0123::/56`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :param ipv6_cidr_block: The ipv6_cidr_block of this RemoveVcnIpv6CidrDetails.
        :type: str
        """
        self._ipv6_cidr_block = ipv6_cidr_block

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExadataInsightResourceForecastTrendSummary(object):
    """
    List of resource id, name , capacity insight value, pattern, historical usage and projected data.
    """

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "LINEAR"
    PATTERN_LINEAR = "LINEAR"

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "MONTHLY_SEASONS"
    PATTERN_MONTHLY_SEASONS = "MONTHLY_SEASONS"

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "MONTHLY_AND_YEARLY_SEASONS"
    PATTERN_MONTHLY_AND_YEARLY_SEASONS = "MONTHLY_AND_YEARLY_SEASONS"

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "WEEKLY_SEASONS"
    PATTERN_WEEKLY_SEASONS = "WEEKLY_SEASONS"

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "WEEKLY_AND_MONTHLY_SEASONS"
    PATTERN_WEEKLY_AND_MONTHLY_SEASONS = "WEEKLY_AND_MONTHLY_SEASONS"

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "WEEKLY_MONTHLY_AND_YEARLY_SEASONS"
    PATTERN_WEEKLY_MONTHLY_AND_YEARLY_SEASONS = "WEEKLY_MONTHLY_AND_YEARLY_SEASONS"

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "WEEKLY_AND_YEARLY_SEASONS"
    PATTERN_WEEKLY_AND_YEARLY_SEASONS = "WEEKLY_AND_YEARLY_SEASONS"

    #: A constant which can be used with the pattern property of a ExadataInsightResourceForecastTrendSummary.
    #: This constant has a value of "YEARLY_SEASONS"
    PATTERN_YEARLY_SEASONS = "YEARLY_SEASONS"

    def __init__(self, **kwargs):
        """
        Initializes a new ExadataInsightResourceForecastTrendSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ExadataInsightResourceForecastTrendSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this ExadataInsightResourceForecastTrendSummary.
        :type name: str

        :param days_to_reach_capacity:
            The value to assign to the days_to_reach_capacity property of this ExadataInsightResourceForecastTrendSummary.
        :type days_to_reach_capacity: int

        :param pattern:
            The value to assign to the pattern property of this ExadataInsightResourceForecastTrendSummary.
            Allowed values for this property are: "LINEAR", "MONTHLY_SEASONS", "MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_SEASONS", "WEEKLY_AND_MONTHLY_SEASONS", "WEEKLY_MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_AND_YEARLY_SEASONS", "YEARLY_SEASONS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type pattern: str

        :param historical_data:
            The value to assign to the historical_data property of this ExadataInsightResourceForecastTrendSummary.
        :type historical_data: list[oci.opsi.models.HistoricalDataItem]

        :param projected_data:
            The value to assign to the projected_data property of this ExadataInsightResourceForecastTrendSummary.
        :type projected_data: list[oci.opsi.models.ProjectedDataItem]

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'days_to_reach_capacity': 'int',
            'pattern': 'str',
            'historical_data': 'list[HistoricalDataItem]',
            'projected_data': 'list[ProjectedDataItem]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'days_to_reach_capacity': 'daysToReachCapacity',
            'pattern': 'pattern',
            'historical_data': 'historicalData',
            'projected_data': 'projectedData'
        }

        self._id = None
        self._name = None
        self._days_to_reach_capacity = None
        self._pattern = None
        self._historical_data = None
        self._projected_data = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ExadataInsightResourceForecastTrendSummary.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ExadataInsightResourceForecastTrendSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExadataInsightResourceForecastTrendSummary.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ExadataInsightResourceForecastTrendSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ExadataInsightResourceForecastTrendSummary.
        The name of the resource.


        :return: The name of this ExadataInsightResourceForecastTrendSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExadataInsightResourceForecastTrendSummary.
        The name of the resource.


        :param name: The name of this ExadataInsightResourceForecastTrendSummary.
        :type: str
        """
        self._name = name

    @property
    def days_to_reach_capacity(self):
        """
        **[Required]** Gets the days_to_reach_capacity of this ExadataInsightResourceForecastTrendSummary.
        Days to reach capacity for a storage server


        :return: The days_to_reach_capacity of this ExadataInsightResourceForecastTrendSummary.
        :rtype: int
        """
        return self._days_to_reach_capacity

    @days_to_reach_capacity.setter
    def days_to_reach_capacity(self, days_to_reach_capacity):
        """
        Sets the days_to_reach_capacity of this ExadataInsightResourceForecastTrendSummary.
        Days to reach capacity for a storage server


        :param days_to_reach_capacity: The days_to_reach_capacity of this ExadataInsightResourceForecastTrendSummary.
        :type: int
        """
        self._days_to_reach_capacity = days_to_reach_capacity

    @property
    def pattern(self):
        """
        **[Required]** Gets the pattern of this ExadataInsightResourceForecastTrendSummary.
        Time series patterns used in the forecasting.

        Allowed values for this property are: "LINEAR", "MONTHLY_SEASONS", "MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_SEASONS", "WEEKLY_AND_MONTHLY_SEASONS", "WEEKLY_MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_AND_YEARLY_SEASONS", "YEARLY_SEASONS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The pattern of this ExadataInsightResourceForecastTrendSummary.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this ExadataInsightResourceForecastTrendSummary.
        Time series patterns used in the forecasting.


        :param pattern: The pattern of this ExadataInsightResourceForecastTrendSummary.
        :type: str
        """
        allowed_values = ["LINEAR", "MONTHLY_SEASONS", "MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_SEASONS", "WEEKLY_AND_MONTHLY_SEASONS", "WEEKLY_MONTHLY_AND_YEARLY_SEASONS", "WEEKLY_AND_YEARLY_SEASONS", "YEARLY_SEASONS"]
        if not value_allowed_none_or_none_sentinel(pattern, allowed_values):
            pattern = 'UNKNOWN_ENUM_VALUE'
        self._pattern = pattern

    @property
    def historical_data(self):
        """
        **[Required]** Gets the historical_data of this ExadataInsightResourceForecastTrendSummary.
        Time series data used for the forecast analysis.


        :return: The historical_data of this ExadataInsightResourceForecastTrendSummary.
        :rtype: list[oci.opsi.models.HistoricalDataItem]
        """
        return self._historical_data

    @historical_data.setter
    def historical_data(self, historical_data):
        """
        Sets the historical_data of this ExadataInsightResourceForecastTrendSummary.
        Time series data used for the forecast analysis.


        :param historical_data: The historical_data of this ExadataInsightResourceForecastTrendSummary.
        :type: list[oci.opsi.models.HistoricalDataItem]
        """
        self._historical_data = historical_data

    @property
    def projected_data(self):
        """
        **[Required]** Gets the projected_data of this ExadataInsightResourceForecastTrendSummary.
        Time series data result of the forecasting analysis.


        :return: The projected_data of this ExadataInsightResourceForecastTrendSummary.
        :rtype: list[oci.opsi.models.ProjectedDataItem]
        """
        return self._projected_data

    @projected_data.setter
    def projected_data(self, projected_data):
        """
        Sets the projected_data of this ExadataInsightResourceForecastTrendSummary.
        Time series data result of the forecasting analysis.


        :param projected_data: The projected_data of this ExadataInsightResourceForecastTrendSummary.
        :type: list[oci.opsi.models.ProjectedDataItem]
        """
        self._projected_data = projected_data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StandardTagNamespaceTemplateSummary(object):
    """
    The template of the standard tag namespace. This object includes necessary details to create the provided standard tag namespace.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StandardTagNamespaceTemplateSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this StandardTagNamespaceTemplateSummary.
        :type description: str

        :param standard_tag_namespace_name:
            The value to assign to the standard_tag_namespace_name property of this StandardTagNamespaceTemplateSummary.
        :type standard_tag_namespace_name: str

        :param status:
            The value to assign to the status property of this StandardTagNamespaceTemplateSummary.
        :type status: str

        """
        self.swagger_types = {
            'description': 'str',
            'standard_tag_namespace_name': 'str',
            'status': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'standard_tag_namespace_name': 'standardTagNamespaceName',
            'status': 'status'
        }

        self._description = None
        self._standard_tag_namespace_name = None
        self._status = None

    @property
    def description(self):
        """
        **[Required]** Gets the description of this StandardTagNamespaceTemplateSummary.
        The default description of the tag namespace that users can use to create the tag namespace


        :return: The description of this StandardTagNamespaceTemplateSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this StandardTagNamespaceTemplateSummary.
        The default description of the tag namespace that users can use to create the tag namespace


        :param description: The description of this StandardTagNamespaceTemplateSummary.
        :type: str
        """
        self._description = description

    @property
    def standard_tag_namespace_name(self):
        """
        **[Required]** Gets the standard_tag_namespace_name of this StandardTagNamespaceTemplateSummary.
        The reserved name of this standard tag namespace


        :return: The standard_tag_namespace_name of this StandardTagNamespaceTemplateSummary.
        :rtype: str
        """
        return self._standard_tag_namespace_name

    @standard_tag_namespace_name.setter
    def standard_tag_namespace_name(self, standard_tag_namespace_name):
        """
        Sets the standard_tag_namespace_name of this StandardTagNamespaceTemplateSummary.
        The reserved name of this standard tag namespace


        :param standard_tag_namespace_name: The standard_tag_namespace_name of this StandardTagNamespaceTemplateSummary.
        :type: str
        """
        self._standard_tag_namespace_name = standard_tag_namespace_name

    @property
    def status(self):
        """
        **[Required]** Gets the status of this StandardTagNamespaceTemplateSummary.
        The status of the standard tag namespace


        :return: The status of this StandardTagNamespaceTemplateSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this StandardTagNamespaceTemplateSummary.
        The status of the standard tag namespace


        :param status: The status of this StandardTagNamespaceTemplateSummary.
        :type: str
        """
        self._status = status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .operation_summary import OperationSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OperationSummaryFromProcedure(OperationSummary):
    """
    The operation object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OperationSummaryFromProcedure object with values from keyword arguments. The default value of the :py:attr:`~oci.data_connectivity.models.OperationSummaryFromProcedure.model_type` attribute
        of this class is ``PROCEDURE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this OperationSummaryFromProcedure.
            Allowed values for this property are: "PROCEDURE"
        :type model_type: str

        :param metadata:
            The value to assign to the metadata property of this OperationSummaryFromProcedure.
        :type metadata: oci.data_connectivity.models.ObjectMetadata

        :param key:
            The value to assign to the key property of this OperationSummaryFromProcedure.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this OperationSummaryFromProcedure.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this OperationSummaryFromProcedure.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param name:
            The value to assign to the name property of this OperationSummaryFromProcedure.
        :type name: str

        :param object_version:
            The value to assign to the object_version property of this OperationSummaryFromProcedure.
        :type object_version: int

        :param external_key:
            The value to assign to the external_key property of this OperationSummaryFromProcedure.
        :type external_key: str

        :param resource_name:
            The value to assign to the resource_name property of this OperationSummaryFromProcedure.
        :type resource_name: str

        :param object_status:
            The value to assign to the object_status property of this OperationSummaryFromProcedure.
        :type object_status: int

        """
        self.swagger_types = {
            'model_type': 'str',
            'metadata': 'ObjectMetadata',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'object_version': 'int',
            'external_key': 'str',
            'resource_name': 'str',
            'object_status': 'int'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'metadata': 'metadata',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'object_version': 'objectVersion',
            'external_key': 'externalKey',
            'resource_name': 'resourceName',
            'object_status': 'objectStatus'
        }

        self._model_type = None
        self._metadata = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._object_version = None
        self._external_key = None
        self._resource_name = None
        self._object_status = None
        self._model_type = 'PROCEDURE'

    @property
    def key(self):
        """
        Gets the key of this OperationSummaryFromProcedure.
        The object key.


        :return: The key of this OperationSummaryFromProcedure.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this OperationSummaryFromProcedure.
        The object key.


        :param key: The key of this OperationSummaryFromProcedure.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this OperationSummaryFromProcedure.
        The model version of the object.


        :return: The model_version of this OperationSummaryFromProcedure.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this OperationSummaryFromProcedure.
        The model version of the object.


        :param model_version: The model_version of this OperationSummaryFromProcedure.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this OperationSummaryFromProcedure.

        :return: The parent_ref of this OperationSummaryFromProcedure.
        :rtype: oci.data_connectivity.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this OperationSummaryFromProcedure.

        :param parent_ref: The parent_ref of this OperationSummaryFromProcedure.
        :type: oci.data_connectivity.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this OperationSummaryFromProcedure.
        The operation name.


        :return: The name of this OperationSummaryFromProcedure.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OperationSummaryFromProcedure.
        The operation name.


        :param name: The name of this OperationSummaryFromProcedure.
        :type: str
        """
        self._name = name

    @property
    def object_version(self):
        """
        Gets the object_version of this OperationSummaryFromProcedure.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this OperationSummaryFromProcedure.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this OperationSummaryFromProcedure.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this OperationSummaryFromProcedure.
        :type: int
        """
        self._object_version = object_version

    @property
    def external_key(self):
        """
        Gets the external_key of this OperationSummaryFromProcedure.
        The external key for the object.


        :return: The external_key of this OperationSummaryFromProcedure.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this OperationSummaryFromProcedure.
        The external key for the object.


        :param external_key: The external_key of this OperationSummaryFromProcedure.
        :type: str
        """
        self._external_key = external_key

    @property
    def resource_name(self):
        """
        Gets the resource_name of this OperationSummaryFromProcedure.
        The resource name.


        :return: The resource_name of this OperationSummaryFromProcedure.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this OperationSummaryFromProcedure.
        The resource name.


        :param resource_name: The resource_name of this OperationSummaryFromProcedure.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def object_status(self):
        """
        Gets the object_status of this OperationSummaryFromProcedure.
        The status of an object that can be set to value 1 for shallow reference across objects, other values reserved.


        :return: The object_status of this OperationSummaryFromProcedure.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this OperationSummaryFromProcedure.
        The status of an object that can be set to value 1 for shallow reference across objects, other values reserved.


        :param object_status: The object_status of this OperationSummaryFromProcedure.
        :type: int
        """
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDbManagementPrivateEndpointDetails(object):
    """
    The details used to create a new Database Management private endpoint.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDbManagementPrivateEndpointDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateDbManagementPrivateEndpointDetails.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDbManagementPrivateEndpointDetails.
        :type compartment_id: str

        :param is_cluster:
            The value to assign to the is_cluster property of this CreateDbManagementPrivateEndpointDetails.
        :type is_cluster: bool

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateDbManagementPrivateEndpointDetails.
        :type subnet_id: str

        :param description:
            The value to assign to the description property of this CreateDbManagementPrivateEndpointDetails.
        :type description: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateDbManagementPrivateEndpointDetails.
        :type nsg_ids: list[str]

        """
        self.swagger_types = {
            'name': 'str',
            'compartment_id': 'str',
            'is_cluster': 'bool',
            'subnet_id': 'str',
            'description': 'str',
            'nsg_ids': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'compartment_id': 'compartmentId',
            'is_cluster': 'isCluster',
            'subnet_id': 'subnetId',
            'description': 'description',
            'nsg_ids': 'nsgIds'
        }

        self._name = None
        self._compartment_id = None
        self._is_cluster = None
        self._subnet_id = None
        self._description = None
        self._nsg_ids = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateDbManagementPrivateEndpointDetails.
        The display name of the Database Management private endpoint.


        :return: The name of this CreateDbManagementPrivateEndpointDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateDbManagementPrivateEndpointDetails.
        The display name of the Database Management private endpoint.


        :param name: The name of this CreateDbManagementPrivateEndpointDetails.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDbManagementPrivateEndpointDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateDbManagementPrivateEndpointDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDbManagementPrivateEndpointDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateDbManagementPrivateEndpointDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_cluster(self):
        """
        Gets the is_cluster of this CreateDbManagementPrivateEndpointDetails.
        Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.


        :return: The is_cluster of this CreateDbManagementPrivateEndpointDetails.
        :rtype: bool
        """
        return self._is_cluster

    @is_cluster.setter
    def is_cluster(self, is_cluster):
        """
        Sets the is_cluster of this CreateDbManagementPrivateEndpointDetails.
        Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.


        :param is_cluster: The is_cluster of this CreateDbManagementPrivateEndpointDetails.
        :type: bool
        """
        self._is_cluster = is_cluster

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this CreateDbManagementPrivateEndpointDetails.
        The `OCID`__ of the subnet.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this CreateDbManagementPrivateEndpointDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateDbManagementPrivateEndpointDetails.
        The `OCID`__ of the subnet.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this CreateDbManagementPrivateEndpointDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def description(self):
        """
        Gets the description of this CreateDbManagementPrivateEndpointDetails.
        The description of the private endpoint.


        :return: The description of this CreateDbManagementPrivateEndpointDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDbManagementPrivateEndpointDetails.
        The description of the private endpoint.


        :param description: The description of this CreateDbManagementPrivateEndpointDetails.
        :type: str
        """
        self._description = description

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateDbManagementPrivateEndpointDetails.
        The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.


        :return: The nsg_ids of this CreateDbManagementPrivateEndpointDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateDbManagementPrivateEndpointDetails.
        The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.


        :param nsg_ids: The nsg_ids of this CreateDbManagementPrivateEndpointDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StoragePerformanceDetails(object):
    """
    Representation of storage performance detail parameters.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StoragePerformanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param size_in_gbs:
            The value to assign to the size_in_gbs property of this StoragePerformanceDetails.
        :type size_in_gbs: int

        :param balanced_disk_performance:
            The value to assign to the balanced_disk_performance property of this StoragePerformanceDetails.
        :type balanced_disk_performance: oci.database.models.DiskPerformanceDetails

        :param high_disk_performance:
            The value to assign to the high_disk_performance property of this StoragePerformanceDetails.
        :type high_disk_performance: oci.database.models.DiskPerformanceDetails

        """
        self.swagger_types = {
            'size_in_gbs': 'int',
            'balanced_disk_performance': 'DiskPerformanceDetails',
            'high_disk_performance': 'DiskPerformanceDetails'
        }

        self.attribute_map = {
            'size_in_gbs': 'sizeInGBs',
            'balanced_disk_performance': 'balancedDiskPerformance',
            'high_disk_performance': 'highDiskPerformance'
        }

        self._size_in_gbs = None
        self._balanced_disk_performance = None
        self._high_disk_performance = None

    @property
    def size_in_gbs(self):
        """
        **[Required]** Gets the size_in_gbs of this StoragePerformanceDetails.
        Size in GBs.


        :return: The size_in_gbs of this StoragePerformanceDetails.
        :rtype: int
        """
        return self._size_in_gbs

    @size_in_gbs.setter
    def size_in_gbs(self, size_in_gbs):
        """
        Sets the size_in_gbs of this StoragePerformanceDetails.
        Size in GBs.


        :param size_in_gbs: The size_in_gbs of this StoragePerformanceDetails.
        :type: int
        """
        self._size_in_gbs = size_in_gbs

    @property
    def balanced_disk_performance(self):
        """
        **[Required]** Gets the balanced_disk_performance of this StoragePerformanceDetails.

        :return: The balanced_disk_performance of this StoragePerformanceDetails.
        :rtype: oci.database.models.DiskPerformanceDetails
        """
        return self._balanced_disk_performance

    @balanced_disk_performance.setter
    def balanced_disk_performance(self, balanced_disk_performance):
        """
        Sets the balanced_disk_performance of this StoragePerformanceDetails.

        :param balanced_disk_performance: The balanced_disk_performance of this StoragePerformanceDetails.
        :type: oci.database.models.DiskPerformanceDetails
        """
        self._balanced_disk_performance = balanced_disk_performance

    @property
    def high_disk_performance(self):
        """
        **[Required]** Gets the high_disk_performance of this StoragePerformanceDetails.

        :return: The high_disk_performance of this StoragePerformanceDetails.
        :rtype: oci.database.models.DiskPerformanceDetails
        """
        return self._high_disk_performance

    @high_disk_performance.setter
    def high_disk_performance(self, high_disk_performance):
        """
        Sets the high_disk_performance of this StoragePerformanceDetails.

        :param high_disk_performance: The high_disk_performance of this StoragePerformanceDetails.
        :type: oci.database.models.DiskPerformanceDetails
        """
        self._high_disk_performance = high_disk_performance

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_autonomous_database_base import CreateAutonomousDatabaseBase
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCrossRegionAutonomousDatabaseDataGuardDetails(CreateAutonomousDatabaseBase):
    """
    Details to create an Autonomous Data Guard association for an existing Autonomous Database where the standby is in a different (remote) region from the source primary database.
    *IMPORTANT*
    Note the following for creating standby databases in cross-region Autonomous Data Guard associations:
    - To create your standby database in a region different from the region of the primary, use the API endpoint of the region in which the standby will be located. For example, if the primary database is in the IAD region, and you want to create the standby in the PHX region, make the API call using the PHX endpoint (https://database.us-phoenix-1.oraclecloud.com). See `API Endpoints`__ for the list of Database Service API endpoints.
    - In the request to create the standby database, the `sourceId` value should be the OCID of the primary database.
    The following parameters are required for the cross-region standby database and must contain the same values as the source Autonomous Database:
    - dbName
    - cpuCoreCount
    - dataStorageSizeInTB
    - dbVersion
    The following parameters are optional for the cross-region standby database. If included in the request, these parameters contain the same values as the source Autonomous Database:
    - customerContacts
    - scheduledOperations
    - isAutoScalingForStorageEnabled
    - definedTags
    - freeformTags
    - licenseModel
    - whitelistedIps
    - isMtlsConnectionRequired
    Example I - Creating a cross-region standby with required parameters only:
    `{
    \"compartmentId\": \"ocid.compartment.oc1..<var>&lt;unique_ID&gt;</var>\",
    \"cpuCoreCount\": 1,
    \"dbName\": \"adatabasedb1\",
    \"sourceId\": \"ocid1.autonomousdatabase.oc1.phx..<var>&lt;unique_ID&gt;</var>\",
    \"dataStorageSizeInTBs\": 1,
    \"source\": \"CROSS_REGION_DATAGUARD\",
    \"adminPassword\" : \"<var>&lt;password&gt;</var>\",
    }`
    Example II - Creating a cross-region standby that specifies optional parameters in addition to the required parameters:
    `{
    \"compartmentId\": \"ocid.compartment.oc1..<var>&lt;unique_ID&gt;</var>\",
    \"cpuCoreCount\": 1,
    \"dbName\": \"adatabasedb1\",
    \"sourceId\": \"ocid1.autonomousdatabase.oc1.phx..<var>&lt;unique_ID&gt;</var>\",
    \"dataStorageSizeInTBs\": 1,
    \"source\": \"CROSS_REGION_DATAGUARD\",
    \"adminPassword\" : \"<var>&lt;password&gt;</var>\",
    \"dbVersion\": \"19c\",
    \"licenseModel\": \"LICENSE_INCLUDED\",
    \"isAutoScalingForStorageEnabled\": \"true\"
    }`

    __ https://docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm#REST_APIs
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCrossRegionAutonomousDatabaseDataGuardDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.CreateCrossRegionAutonomousDatabaseDataGuardDetails.source` attribute
        of this class is ``CROSS_REGION_DATAGUARD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type compartment_id: str

        :param character_set:
            The value to assign to the character_set property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type character_set: str

        :param ncharacter_set:
            The value to assign to the ncharacter_set property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type ncharacter_set: str

        :param db_name:
            The value to assign to the db_name property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type db_name: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type cpu_core_count: int

        :param ocpu_count:
            The value to assign to the ocpu_count property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type ocpu_count: float

        :param db_workload:
            The value to assign to the db_workload property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
            Allowed values for this property are: "OLTP", "DW", "AJD", "APEX"
        :type db_workload: str

        :param data_storage_size_in_tbs:
            The value to assign to the data_storage_size_in_tbs property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type data_storage_size_in_tbs: int

        :param data_storage_size_in_gbs:
            The value to assign to the data_storage_size_in_gbs property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type data_storage_size_in_gbs: int

        :param is_free_tier:
            The value to assign to the is_free_tier property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_free_tier: bool

        :param kms_key_id:
            The value to assign to the kms_key_id property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type kms_key_id: str

        :param vault_id:
            The value to assign to the vault_id property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type vault_id: str

        :param admin_password:
            The value to assign to the admin_password property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type admin_password: str

        :param display_name:
            The value to assign to the display_name property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type display_name: str

        :param license_model:
            The value to assign to the license_model property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param is_preview_version_with_service_terms_accepted:
            The value to assign to the is_preview_version_with_service_terms_accepted property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_preview_version_with_service_terms_accepted: bool

        :param is_auto_scaling_enabled:
            The value to assign to the is_auto_scaling_enabled property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_auto_scaling_enabled: bool

        :param is_dedicated:
            The value to assign to the is_dedicated property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_dedicated: bool

        :param autonomous_container_database_id:
            The value to assign to the autonomous_container_database_id property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type autonomous_container_database_id: str

        :param is_access_control_enabled:
            The value to assign to the is_access_control_enabled property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_access_control_enabled: bool

        :param whitelisted_ips:
            The value to assign to the whitelisted_ips property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type whitelisted_ips: list[str]

        :param are_primary_whitelisted_ips_used:
            The value to assign to the are_primary_whitelisted_ips_used property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type are_primary_whitelisted_ips_used: bool

        :param standby_whitelisted_ips:
            The value to assign to the standby_whitelisted_ips property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type standby_whitelisted_ips: list[str]

        :param is_data_guard_enabled:
            The value to assign to the is_data_guard_enabled property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_data_guard_enabled: bool

        :param is_local_data_guard_enabled:
            The value to assign to the is_local_data_guard_enabled property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_local_data_guard_enabled: bool

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type subnet_id: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type nsg_ids: list[str]

        :param private_endpoint_label:
            The value to assign to the private_endpoint_label property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type private_endpoint_label: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param db_version:
            The value to assign to the db_version property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type db_version: str

        :param source:
            The value to assign to the source property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
            Allowed values for this property are: "NONE", "DATABASE", "BACKUP_FROM_ID", "BACKUP_FROM_TIMESTAMP", "CLONE_TO_REFRESHABLE", "CROSS_REGION_DATAGUARD"
        :type source: str

        :param customer_contacts:
            The value to assign to the customer_contacts property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type customer_contacts: list[oci.database.models.CustomerContact]

        :param is_mtls_connection_required:
            The value to assign to the is_mtls_connection_required property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_mtls_connection_required: bool

        :param autonomous_maintenance_schedule_type:
            The value to assign to the autonomous_maintenance_schedule_type property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
            Allowed values for this property are: "EARLY", "REGULAR"
        :type autonomous_maintenance_schedule_type: str

        :param scheduled_operations:
            The value to assign to the scheduled_operations property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type scheduled_operations: list[oci.database.models.ScheduledOperationDetails]

        :param is_auto_scaling_for_storage_enabled:
            The value to assign to the is_auto_scaling_for_storage_enabled property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type is_auto_scaling_for_storage_enabled: bool

        :param max_cpu_core_count:
            The value to assign to the max_cpu_core_count property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type max_cpu_core_count: int

        :param database_edition:
            The value to assign to the database_edition property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type database_edition: str

        :param source_id:
            The value to assign to the source_id property of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type source_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'character_set': 'str',
            'ncharacter_set': 'str',
            'db_name': 'str',
            'cpu_core_count': 'int',
            'ocpu_count': 'float',
            'db_workload': 'str',
            'data_storage_size_in_tbs': 'int',
            'data_storage_size_in_gbs': 'int',
            'is_free_tier': 'bool',
            'kms_key_id': 'str',
            'vault_id': 'str',
            'admin_password': 'str',
            'display_name': 'str',
            'license_model': 'str',
            'is_preview_version_with_service_terms_accepted': 'bool',
            'is_auto_scaling_enabled': 'bool',
            'is_dedicated': 'bool',
            'autonomous_container_database_id': 'str',
            'is_access_control_enabled': 'bool',
            'whitelisted_ips': 'list[str]',
            'are_primary_whitelisted_ips_used': 'bool',
            'standby_whitelisted_ips': 'list[str]',
            'is_data_guard_enabled': 'bool',
            'is_local_data_guard_enabled': 'bool',
            'subnet_id': 'str',
            'nsg_ids': 'list[str]',
            'private_endpoint_label': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'db_version': 'str',
            'source': 'str',
            'customer_contacts': 'list[CustomerContact]',
            'is_mtls_connection_required': 'bool',
            'autonomous_maintenance_schedule_type': 'str',
            'scheduled_operations': 'list[ScheduledOperationDetails]',
            'is_auto_scaling_for_storage_enabled': 'bool',
            'max_cpu_core_count': 'int',
            'database_edition': 'str',
            'source_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'character_set': 'characterSet',
            'ncharacter_set': 'ncharacterSet',
            'db_name': 'dbName',
            'cpu_core_count': 'cpuCoreCount',
            'ocpu_count': 'ocpuCount',
            'db_workload': 'dbWorkload',
            'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
            'data_storage_size_in_gbs': 'dataStorageSizeInGBs',
            'is_free_tier': 'isFreeTier',
            'kms_key_id': 'kmsKeyId',
            'vault_id': 'vaultId',
            'admin_password': 'adminPassword',
            'display_name': 'displayName',
            'license_model': 'licenseModel',
            'is_preview_version_with_service_terms_accepted': 'isPreviewVersionWithServiceTermsAccepted',
            'is_auto_scaling_enabled': 'isAutoScalingEnabled',
            'is_dedicated': 'isDedicated',
            'autonomous_container_database_id': 'autonomousContainerDatabaseId',
            'is_access_control_enabled': 'isAccessControlEnabled',
            'whitelisted_ips': 'whitelistedIps',
            'are_primary_whitelisted_ips_used': 'arePrimaryWhitelistedIpsUsed',
            'standby_whitelisted_ips': 'standbyWhitelistedIps',
            'is_data_guard_enabled': 'isDataGuardEnabled',
            'is_local_data_guard_enabled': 'isLocalDataGuardEnabled',
            'subnet_id': 'subnetId',
            'nsg_ids': 'nsgIds',
            'private_endpoint_label': 'privateEndpointLabel',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'db_version': 'dbVersion',
            'source': 'source',
            'customer_contacts': 'customerContacts',
            'is_mtls_connection_required': 'isMtlsConnectionRequired',
            'autonomous_maintenance_schedule_type': 'autonomousMaintenanceScheduleType',
            'scheduled_operations': 'scheduledOperations',
            'is_auto_scaling_for_storage_enabled': 'isAutoScalingForStorageEnabled',
            'max_cpu_core_count': 'maxCpuCoreCount',
            'database_edition': 'databaseEdition',
            'source_id': 'sourceId'
        }

        self._compartment_id = None
        self._character_set = None
        self._ncharacter_set = None
        self._db_name = None
        self._cpu_core_count = None
        self._ocpu_count = None
        self._db_workload = None
        self._data_storage_size_in_tbs = None
        self._data_storage_size_in_gbs = None
        self._is_free_tier = None
        self._kms_key_id = None
        self._vault_id = None
        self._admin_password = None
        self._display_name = None
        self._license_model = None
        self._is_preview_version_with_service_terms_accepted = None
        self._is_auto_scaling_enabled = None
        self._is_dedicated = None
        self._autonomous_container_database_id = None
        self._is_access_control_enabled = None
        self._whitelisted_ips = None
        self._are_primary_whitelisted_ips_used = None
        self._standby_whitelisted_ips = None
        self._is_data_guard_enabled = None
        self._is_local_data_guard_enabled = None
        self._subnet_id = None
        self._nsg_ids = None
        self._private_endpoint_label = None
        self._freeform_tags = None
        self._defined_tags = None
        self._db_version = None
        self._source = None
        self._customer_contacts = None
        self._is_mtls_connection_required = None
        self._autonomous_maintenance_schedule_type = None
        self._scheduled_operations = None
        self._is_auto_scaling_for_storage_enabled = None
        self._max_cpu_core_count = None
        self._database_edition = None
        self._source_id = None
        self._source = 'CROSS_REGION_DATAGUARD'

    @property
    def source_id(self):
        """
        **[Required]** Gets the source_id of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        The `OCID`__ of the source Autonomous Database that will be used to create a new standby database for the Data Guard association.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The source_id of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        The `OCID`__ of the source Autonomous Database that will be used to create a new standby database for the Data Guard association.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param source_id: The source_id of this CreateCrossRegionAutonomousDatabaseDataGuardDetails.
        :type: str
        """
        self._source_id = source_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .association import Association
from .association_collection import AssociationCollection
from .association_summary import AssociationSummary
from .ca_bundle import CaBundle
from .ca_bundle_collection import CaBundleCollection
from .ca_bundle_summary import CaBundleSummary
from .certificate import Certificate
from .certificate_authority import CertificateAuthority
from .certificate_authority_collection import CertificateAuthorityCollection
from .certificate_authority_issuance_expiry_rule import CertificateAuthorityIssuanceExpiryRule
from .certificate_authority_rule import CertificateAuthorityRule
from .certificate_authority_summary import CertificateAuthoritySummary
from .certificate_authority_version import CertificateAuthorityVersion
from .certificate_authority_version_collection import CertificateAuthorityVersionCollection
from .certificate_authority_version_summary import CertificateAuthorityVersionSummary
from .certificate_collection import CertificateCollection
from .certificate_renewal_rule import CertificateRenewalRule
from .certificate_revocation_list_details import CertificateRevocationListDetails
from .certificate_rule import CertificateRule
from .certificate_subject import CertificateSubject
from .certificate_subject_alternative_name import CertificateSubjectAlternativeName
from .certificate_summary import CertificateSummary
from .certificate_version import CertificateVersion
from .certificate_version_collection import CertificateVersionCollection
from .certificate_version_summary import CertificateVersionSummary
from .change_ca_bundle_compartment_details import ChangeCaBundleCompartmentDetails
from .change_certificate_authority_compartment_details import ChangeCertificateAuthorityCompartmentDetails
from .change_certificate_compartment_details import ChangeCertificateCompartmentDetails
from .create_ca_bundle_details import CreateCaBundleDetails
from .create_certificate_authority_config_details import CreateCertificateAuthorityConfigDetails
from .create_certificate_authority_details import CreateCertificateAuthorityDetails
from .create_certificate_by_importing_config_details import CreateCertificateByImportingConfigDetails
from .create_certificate_config_details import CreateCertificateConfigDetails
from .create_certificate_details import CreateCertificateDetails
from .create_certificate_issued_by_internal_ca_config_details import CreateCertificateIssuedByInternalCaConfigDetails
from .create_certificate_managed_externally_issued_by_internal_ca_config_details import CreateCertificateManagedExternallyIssuedByInternalCaConfigDetails
from .create_root_ca_by_generating_internally_config_details import CreateRootCaByGeneratingInternallyConfigDetails
from .create_subordinate_ca_issued_by_internal_ca_config_details import CreateSubordinateCaIssuedByInternalCaConfigDetails
from .object_storage_bucket_config_details import ObjectStorageBucketConfigDetails
from .revocation_status import RevocationStatus
from .revoke_certificate_authority_version_details import RevokeCertificateAuthorityVersionDetails
from .revoke_certificate_version_details import RevokeCertificateVersionDetails
from .schedule_certificate_authority_deletion_details import ScheduleCertificateAuthorityDeletionDetails
from .schedule_certificate_authority_version_deletion_details import ScheduleCertificateAuthorityVersionDeletionDetails
from .schedule_certificate_deletion_details import ScheduleCertificateDeletionDetails
from .schedule_certificate_version_deletion_details import ScheduleCertificateVersionDeletionDetails
from .update_ca_bundle_details import UpdateCaBundleDetails
from .update_certificate_authority_config_details import UpdateCertificateAuthorityConfigDetails
from .update_certificate_authority_details import UpdateCertificateAuthorityDetails
from .update_certificate_by_importing_config_details import UpdateCertificateByImportingConfigDetails
from .update_certificate_config_details import UpdateCertificateConfigDetails
from .update_certificate_details import UpdateCertificateDetails
from .update_certificate_issued_by_internal_ca_config_details import UpdateCertificateIssuedByInternalCaConfigDetails
from .update_certificate_managed_externally_issued_by_internal_ca_config_details import UpdateCertificateManagedExternallyIssuedByInternalCaConfigDetails
from .update_root_ca_by_generating_internally_config_details import UpdateRootCaByGeneratingInternallyConfigDetails
from .update_subordinate_ca_issued_by_internal_ca_config_details import UpdateSubordinateCaIssuedByInternalCaConfigDetails
from .validity import Validity

# Maps type names to classes for certificates_management services.
certificates_management_type_mapping = {
    "Association": Association,
    "AssociationCollection": AssociationCollection,
    "AssociationSummary": AssociationSummary,
    "CaBundle": CaBundle,
    "CaBundleCollection": CaBundleCollection,
    "CaBundleSummary": CaBundleSummary,
    "Certificate": Certificate,
    "CertificateAuthority": CertificateAuthority,
    "CertificateAuthorityCollection": CertificateAuthorityCollection,
    "CertificateAuthorityIssuanceExpiryRule": CertificateAuthorityIssuanceExpiryRule,
    "CertificateAuthorityRule": CertificateAuthorityRule,
    "CertificateAuthoritySummary": CertificateAuthoritySummary,
    "CertificateAuthorityVersion": CertificateAuthorityVersion,
    "CertificateAuthorityVersionCollection": CertificateAuthorityVersionCollection,
    "CertificateAuthorityVersionSummary": CertificateAuthorityVersionSummary,
    "CertificateCollection": CertificateCollection,
    "CertificateRenewalRule": CertificateRenewalRule,
    "CertificateRevocationListDetails": CertificateRevocationListDetails,
    "CertificateRule": CertificateRule,
    "CertificateSubject": CertificateSubject,
    "CertificateSubjectAlternativeName": CertificateSubjectAlternativeName,
    "CertificateSummary": CertificateSummary,
    "CertificateVersion": CertificateVersion,
    "CertificateVersionCollection": CertificateVersionCollection,
    "CertificateVersionSummary": CertificateVersionSummary,
    "ChangeCaBundleCompartmentDetails": ChangeCaBundleCompartmentDetails,
    "ChangeCertificateAuthorityCompartmentDetails": ChangeCertificateAuthorityCompartmentDetails,
    "ChangeCertificateCompartmentDetails": ChangeCertificateCompartmentDetails,
    "CreateCaBundleDetails": CreateCaBundleDetails,
    "CreateCertificateAuthorityConfigDetails": CreateCertificateAuthorityConfigDetails,
    "CreateCertificateAuthorityDetails": CreateCertificateAuthorityDetails,
    "CreateCertificateByImportingConfigDetails": CreateCertificateByImportingConfigDetails,
    "CreateCertificateConfigDetails": CreateCertificateConfigDetails,
    "CreateCertificateDetails": CreateCertificateDetails,
    "CreateCertificateIssuedByInternalCaConfigDetails": CreateCertificateIssuedByInternalCaConfigDetails,
    "CreateCertificateManagedExternallyIssuedByInternalCaConfigDetails": CreateCertificateManagedExternallyIssuedByInternalCaConfigDetails,
    "CreateRootCaByGeneratingInternallyConfigDetails": CreateRootCaByGeneratingInternallyConfigDetails,
    "CreateSubordinateCaIssuedByInternalCaConfigDetails": CreateSubordinateCaIssuedByInternalCaConfigDetails,
    "ObjectStorageBucketConfigDetails": ObjectStorageBucketConfigDetails,
    "RevocationStatus": RevocationStatus,
    "RevokeCertificateAuthorityVersionDetails": RevokeCertificateAuthorityVersionDetails,
    "RevokeCertificateVersionDetails": RevokeCertificateVersionDetails,
    "ScheduleCertificateAuthorityDeletionDetails": ScheduleCertificateAuthorityDeletionDetails,
    "ScheduleCertificateAuthorityVersionDeletionDetails": ScheduleCertificateAuthorityVersionDeletionDetails,
    "ScheduleCertificateDeletionDetails": ScheduleCertificateDeletionDetails,
    "ScheduleCertificateVersionDeletionDetails": ScheduleCertificateVersionDeletionDetails,
    "UpdateCaBundleDetails": UpdateCaBundleDetails,
    "UpdateCertificateAuthorityConfigDetails": UpdateCertificateAuthorityConfigDetails,
    "UpdateCertificateAuthorityDetails": UpdateCertificateAuthorityDetails,
    "UpdateCertificateByImportingConfigDetails": UpdateCertificateByImportingConfigDetails,
    "UpdateCertificateConfigDetails": UpdateCertificateConfigDetails,
    "UpdateCertificateDetails": UpdateCertificateDetails,
    "UpdateCertificateIssuedByInternalCaConfigDetails": UpdateCertificateIssuedByInternalCaConfigDetails,
    "UpdateCertificateManagedExternallyIssuedByInternalCaConfigDetails": UpdateCertificateManagedExternallyIssuedByInternalCaConfigDetails,
    "UpdateRootCaByGeneratingInternallyConfigDetails": UpdateRootCaByGeneratingInternallyConfigDetails,
    "UpdateSubordinateCaIssuedByInternalCaConfigDetails": UpdateSubordinateCaIssuedByInternalCaConfigDetails,
    "Validity": Validity
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RelatedEventSummary(object):
    """
    Event occurrence on managed instances.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RelatedEventSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this RelatedEventSummary.
        :type id: str

        :param instance_id:
            The value to assign to the instance_id property of this RelatedEventSummary.
        :type instance_id: str

        :param timestamp:
            The value to assign to the timestamp property of this RelatedEventSummary.
        :type timestamp: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'instance_id': 'str',
            'timestamp': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'instance_id': 'instanceId',
            'timestamp': 'timestamp'
        }

        self._id = None
        self._instance_id = None
        self._timestamp = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this RelatedEventSummary.
        OCID identifier of the event


        :return: The id of this RelatedEventSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RelatedEventSummary.
        OCID identifier of the event


        :param id: The id of this RelatedEventSummary.
        :type: str
        """
        self._id = id

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this RelatedEventSummary.
        OCID identifier of the instance


        :return: The instance_id of this RelatedEventSummary.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this RelatedEventSummary.
        OCID identifier of the instance


        :param instance_id: The instance_id of this RelatedEventSummary.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def timestamp(self):
        """
        Gets the timestamp of this RelatedEventSummary.
        time occurence


        :return: The timestamp of this RelatedEventSummary.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this RelatedEventSummary.
        time occurence


        :param timestamp: The timestamp of this RelatedEventSummary.
        :type: datetime
        """
        self._timestamp = timestamp

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .data_object_column_unit import DataObjectColumnUnit
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataObjectDataSizeColumnUnit(DataObjectColumnUnit):
    """
    Unit details of a data object column of DATA_SIZE unit category.
    """

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "CHARACTER"
    UNIT_CHARACTER = "CHARACTER"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "BLOCK"
    UNIT_BLOCK = "BLOCK"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "BIT"
    UNIT_BIT = "BIT"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "BYTE"
    UNIT_BYTE = "BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "KILO_BYTE"
    UNIT_KILO_BYTE = "KILO_BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "MEGA_BYTE"
    UNIT_MEGA_BYTE = "MEGA_BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "GIGA_BYTE"
    UNIT_GIGA_BYTE = "GIGA_BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "TERA_BYTE"
    UNIT_TERA_BYTE = "TERA_BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "PETA_BYTE"
    UNIT_PETA_BYTE = "PETA_BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "EXA_BYTE"
    UNIT_EXA_BYTE = "EXA_BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "ZETTA_BYTE"
    UNIT_ZETTA_BYTE = "ZETTA_BYTE"

    #: A constant which can be used with the unit property of a DataObjectDataSizeColumnUnit.
    #: This constant has a value of "YOTTA_BYTE"
    UNIT_YOTTA_BYTE = "YOTTA_BYTE"

    def __init__(self, **kwargs):
        """
        Initializes a new DataObjectDataSizeColumnUnit object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.DataObjectDataSizeColumnUnit.unit_category` attribute
        of this class is ``DATA_SIZE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param unit_category:
            The value to assign to the unit_category property of this DataObjectDataSizeColumnUnit.
            Allowed values for this property are: "DATA_SIZE", "TIME", "POWER", "TEMPERATURE", "CORE", "RATE", "FREQUENCY", "OTHER_STANDARD", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type unit_category: str

        :param display_name:
            The value to assign to the display_name property of this DataObjectDataSizeColumnUnit.
        :type display_name: str

        :param unit:
            The value to assign to the unit property of this DataObjectDataSizeColumnUnit.
            Allowed values for this property are: "CHARACTER", "BLOCK", "BIT", "BYTE", "KILO_BYTE", "MEGA_BYTE", "GIGA_BYTE", "TERA_BYTE", "PETA_BYTE", "EXA_BYTE", "ZETTA_BYTE", "YOTTA_BYTE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type unit: str

        """
        self.swagger_types = {
            'unit_category': 'str',
            'display_name': 'str',
            'unit': 'str'
        }

        self.attribute_map = {
            'unit_category': 'unitCategory',
            'display_name': 'displayName',
            'unit': 'unit'
        }

        self._unit_category = None
        self._display_name = None
        self._unit = None
        self._unit_category = 'DATA_SIZE'

    @property
    def unit(self):
        """
        Gets the unit of this DataObjectDataSizeColumnUnit.
        Data size unit.

        Allowed values for this property are: "CHARACTER", "BLOCK", "BIT", "BYTE", "KILO_BYTE", "MEGA_BYTE", "GIGA_BYTE", "TERA_BYTE", "PETA_BYTE", "EXA_BYTE", "ZETTA_BYTE", "YOTTA_BYTE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The unit of this DataObjectDataSizeColumnUnit.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this DataObjectDataSizeColumnUnit.
        Data size unit.


        :param unit: The unit of this DataObjectDataSizeColumnUnit.
        :type: str
        """
        allowed_values = ["CHARACTER", "BLOCK", "BIT", "BYTE", "KILO_BYTE", "MEGA_BYTE", "GIGA_BYTE", "TERA_BYTE", "PETA_BYTE", "EXA_BYTE", "ZETTA_BYTE", "YOTTA_BYTE"]
        if not value_allowed_none_or_none_sentinel(unit, allowed_values):
            unit = 'UNKNOWN_ENUM_VALUE'
        self._unit = unit

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpgradeDbSystemDetails(object):
    """
    Details for upgrading the operating system and Oracle Grid Infrastructure (GI) of a DB system.
    """

    #: A constant which can be used with the action property of a UpgradeDbSystemDetails.
    #: This constant has a value of "PRECHECK"
    ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the action property of a UpgradeDbSystemDetails.
    #: This constant has a value of "ROLLBACK"
    ACTION_ROLLBACK = "ROLLBACK"

    #: A constant which can be used with the action property of a UpgradeDbSystemDetails.
    #: This constant has a value of "UPDATE_SNAPSHOT_RETENTION_DAYS"
    ACTION_UPDATE_SNAPSHOT_RETENTION_DAYS = "UPDATE_SNAPSHOT_RETENTION_DAYS"

    #: A constant which can be used with the action property of a UpgradeDbSystemDetails.
    #: This constant has a value of "UPGRADE"
    ACTION_UPGRADE = "UPGRADE"

    def __init__(self, **kwargs):
        """
        Initializes a new UpgradeDbSystemDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action:
            The value to assign to the action property of this UpgradeDbSystemDetails.
            Allowed values for this property are: "PRECHECK", "ROLLBACK", "UPDATE_SNAPSHOT_RETENTION_DAYS", "UPGRADE"
        :type action: str

        :param snapshot_retention_period_in_days:
            The value to assign to the snapshot_retention_period_in_days property of this UpgradeDbSystemDetails.
        :type snapshot_retention_period_in_days: int

        :param new_gi_version:
            The value to assign to the new_gi_version property of this UpgradeDbSystemDetails.
        :type new_gi_version: str

        :param is_snapshot_retention_days_force_updated:
            The value to assign to the is_snapshot_retention_days_force_updated property of this UpgradeDbSystemDetails.
        :type is_snapshot_retention_days_force_updated: bool

        """
        self.swagger_types = {
            'action': 'str',
            'snapshot_retention_period_in_days': 'int',
            'new_gi_version': 'str',
            'is_snapshot_retention_days_force_updated': 'bool'
        }

        self.attribute_map = {
            'action': 'action',
            'snapshot_retention_period_in_days': 'snapshotRetentionPeriodInDays',
            'new_gi_version': 'newGiVersion',
            'is_snapshot_retention_days_force_updated': 'isSnapshotRetentionDaysForceUpdated'
        }

        self._action = None
        self._snapshot_retention_period_in_days = None
        self._new_gi_version = None
        self._is_snapshot_retention_days_force_updated = None

    @property
    def action(self):
        """
        **[Required]** Gets the action of this UpgradeDbSystemDetails.
        The operating system upgrade action.

        Allowed values for this property are: "PRECHECK", "ROLLBACK", "UPDATE_SNAPSHOT_RETENTION_DAYS", "UPGRADE"


        :return: The action of this UpgradeDbSystemDetails.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this UpgradeDbSystemDetails.
        The operating system upgrade action.


        :param action: The action of this UpgradeDbSystemDetails.
        :type: str
        """
        allowed_values = ["PRECHECK", "ROLLBACK", "UPDATE_SNAPSHOT_RETENTION_DAYS", "UPGRADE"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            raise ValueError(
                "Invalid value for `action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._action = action

    @property
    def snapshot_retention_period_in_days(self):
        """
        Gets the snapshot_retention_period_in_days of this UpgradeDbSystemDetails.
        The retention period, in days, for the snapshot that allows you to perform a rollback of the upgrade operation. After this number of days passes, you cannot roll back the upgrade.


        :return: The snapshot_retention_period_in_days of this UpgradeDbSystemDetails.
        :rtype: int
        """
        return self._snapshot_retention_period_in_days

    @snapshot_retention_period_in_days.setter
    def snapshot_retention_period_in_days(self, snapshot_retention_period_in_days):
        """
        Sets the snapshot_retention_period_in_days of this UpgradeDbSystemDetails.
        The retention period, in days, for the snapshot that allows you to perform a rollback of the upgrade operation. After this number of days passes, you cannot roll back the upgrade.


        :param snapshot_retention_period_in_days: The snapshot_retention_period_in_days of this UpgradeDbSystemDetails.
        :type: int
        """
        self._snapshot_retention_period_in_days = snapshot_retention_period_in_days

    @property
    def new_gi_version(self):
        """
        Gets the new_gi_version of this UpgradeDbSystemDetails.
        A valid Oracle Grid Infrastructure (GI) software version.


        :return: The new_gi_version of this UpgradeDbSystemDetails.
        :rtype: str
        """
        return self._new_gi_version

    @new_gi_version.setter
    def new_gi_version(self, new_gi_version):
        """
        Sets the new_gi_version of this UpgradeDbSystemDetails.
        A valid Oracle Grid Infrastructure (GI) software version.


        :param new_gi_version: The new_gi_version of this UpgradeDbSystemDetails.
        :type: str
        """
        self._new_gi_version = new_gi_version

    @property
    def is_snapshot_retention_days_force_updated(self):
        """
        Gets the is_snapshot_retention_days_force_updated of this UpgradeDbSystemDetails.
        If true, rollback time is updated even if operating system upgrade history contains errors.


        :return: The is_snapshot_retention_days_force_updated of this UpgradeDbSystemDetails.
        :rtype: bool
        """
        return self._is_snapshot_retention_days_force_updated

    @is_snapshot_retention_days_force_updated.setter
    def is_snapshot_retention_days_force_updated(self, is_snapshot_retention_days_force_updated):
        """
        Sets the is_snapshot_retention_days_force_updated of this UpgradeDbSystemDetails.
        If true, rollback time is updated even if operating system upgrade history contains errors.


        :param is_snapshot_retention_days_force_updated: The is_snapshot_retention_days_force_updated of this UpgradeDbSystemDetails.
        :type: bool
        """
        self._is_snapshot_retention_days_force_updated = is_snapshot_retention_days_force_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .function_provisioned_concurrency_config import FunctionProvisionedConcurrencyConfig
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConstantProvisionedConcurrencyConfig(FunctionProvisionedConcurrencyConfig):
    """
    Configuration specifying a constant amount of provisioned concurrency.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConstantProvisionedConcurrencyConfig object with values from keyword arguments. The default value of the :py:attr:`~oci.functions.models.ConstantProvisionedConcurrencyConfig.strategy` attribute
        of this class is ``CONSTANT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param strategy:
            The value to assign to the strategy property of this ConstantProvisionedConcurrencyConfig.
            Allowed values for this property are: "CONSTANT", "NONE"
        :type strategy: str

        :param count:
            The value to assign to the count property of this ConstantProvisionedConcurrencyConfig.
        :type count: int

        """
        self.swagger_types = {
            'strategy': 'str',
            'count': 'int'
        }

        self.attribute_map = {
            'strategy': 'strategy',
            'count': 'count'
        }

        self._strategy = None
        self._count = None
        self._strategy = 'CONSTANT'

    @property
    def count(self):
        """
        **[Required]** Gets the count of this ConstantProvisionedConcurrencyConfig.

        :return: The count of this ConstantProvisionedConcurrencyConfig.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this ConstantProvisionedConcurrencyConfig.

        :param count: The count of this ConstantProvisionedConcurrencyConfig.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .auto_scale_policy_details import AutoScalePolicyDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetricBasedHorizontalScalingPolicyDetails(AutoScalePolicyDetails):
    """
    Details of a metric based horizontal autoscaling policy.

    In a metric-based autoscaling policy, an autoscaling action is triggered when a performance metric exceeds a threshold.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetricBasedHorizontalScalingPolicyDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.bds.models.MetricBasedHorizontalScalingPolicyDetails.policy_type` attribute
        of this class is ``METRIC_BASED_HORIZONTAL_SCALING_POLICY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this MetricBasedHorizontalScalingPolicyDetails.
            Allowed values for this property are: "METRIC_BASED_VERTICAL_SCALING_POLICY", "METRIC_BASED_HORIZONTAL_SCALING_POLICY", "SCHEDULE_BASED_VERTICAL_SCALING_POLICY", "SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY"
        :type policy_type: str

        :param trigger_type:
            The value to assign to the trigger_type property of this MetricBasedHorizontalScalingPolicyDetails.
            Allowed values for this property are: "METRIC_BASED", "SCHEDULE_BASED"
        :type trigger_type: str

        :param action_type:
            The value to assign to the action_type property of this MetricBasedHorizontalScalingPolicyDetails.
            Allowed values for this property are: "VERTICAL_SCALING", "HORIZONTAL_SCALING"
        :type action_type: str

        :param scale_out_config:
            The value to assign to the scale_out_config property of this MetricBasedHorizontalScalingPolicyDetails.
        :type scale_out_config: oci.bds.models.MetricBasedHorizontalScaleOutConfig

        :param scale_in_config:
            The value to assign to the scale_in_config property of this MetricBasedHorizontalScalingPolicyDetails.
        :type scale_in_config: oci.bds.models.MetricBasedHorizontalScaleInConfig

        """
        self.swagger_types = {
            'policy_type': 'str',
            'trigger_type': 'str',
            'action_type': 'str',
            'scale_out_config': 'MetricBasedHorizontalScaleOutConfig',
            'scale_in_config': 'MetricBasedHorizontalScaleInConfig'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'trigger_type': 'triggerType',
            'action_type': 'actionType',
            'scale_out_config': 'scaleOutConfig',
            'scale_in_config': 'scaleInConfig'
        }

        self._policy_type = None
        self._trigger_type = None
        self._action_type = None
        self._scale_out_config = None
        self._scale_in_config = None
        self._policy_type = 'METRIC_BASED_HORIZONTAL_SCALING_POLICY'

    @property
    def scale_out_config(self):
        """
        Gets the scale_out_config of this MetricBasedHorizontalScalingPolicyDetails.

        :return: The scale_out_config of this MetricBasedHorizontalScalingPolicyDetails.
        :rtype: oci.bds.models.MetricBasedHorizontalScaleOutConfig
        """
        return self._scale_out_config

    @scale_out_config.setter
    def scale_out_config(self, scale_out_config):
        """
        Sets the scale_out_config of this MetricBasedHorizontalScalingPolicyDetails.

        :param scale_out_config: The scale_out_config of this MetricBasedHorizontalScalingPolicyDetails.
        :type: oci.bds.models.MetricBasedHorizontalScaleOutConfig
        """
        self._scale_out_config = scale_out_config

    @property
    def scale_in_config(self):
        """
        Gets the scale_in_config of this MetricBasedHorizontalScalingPolicyDetails.

        :return: The scale_in_config of this MetricBasedHorizontalScalingPolicyDetails.
        :rtype: oci.bds.models.MetricBasedHorizontalScaleInConfig
        """
        return self._scale_in_config

    @scale_in_config.setter
    def scale_in_config(self, scale_in_config):
        """
        Sets the scale_in_config of this MetricBasedHorizontalScalingPolicyDetails.

        :param scale_in_config: The scale_in_config of this MetricBasedHorizontalScalingPolicyDetails.
        :type: oci.bds.models.MetricBasedHorizontalScaleInConfig
        """
        self._scale_in_config = scale_in_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateReportDetails(object):
    """
    Details for the report generation.
    """

    #: A constant which can be used with the mime_type property of a GenerateReportDetails.
    #: This constant has a value of "PDF"
    MIME_TYPE_PDF = "PDF"

    #: A constant which can be used with the mime_type property of a GenerateReportDetails.
    #: This constant has a value of "XLS"
    MIME_TYPE_XLS = "XLS"

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateReportDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this GenerateReportDetails.
        :type display_name: str

        :param target_ids:
            The value to assign to the target_ids property of this GenerateReportDetails.
        :type target_ids: list[str]

        :param description:
            The value to assign to the description property of this GenerateReportDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this GenerateReportDetails.
        :type compartment_id: str

        :param mime_type:
            The value to assign to the mime_type property of this GenerateReportDetails.
            Allowed values for this property are: "PDF", "XLS"
        :type mime_type: str

        :param time_less_than:
            The value to assign to the time_less_than property of this GenerateReportDetails.
        :type time_less_than: datetime

        :param time_greater_than:
            The value to assign to the time_greater_than property of this GenerateReportDetails.
        :type time_greater_than: datetime

        :param row_limit:
            The value to assign to the row_limit property of this GenerateReportDetails.
        :type row_limit: int

        """
        self.swagger_types = {
            'display_name': 'str',
            'target_ids': 'list[str]',
            'description': 'str',
            'compartment_id': 'str',
            'mime_type': 'str',
            'time_less_than': 'datetime',
            'time_greater_than': 'datetime',
            'row_limit': 'int'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'target_ids': 'targetIds',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'mime_type': 'mimeType',
            'time_less_than': 'timeLessThan',
            'time_greater_than': 'timeGreaterThan',
            'row_limit': 'rowLimit'
        }

        self._display_name = None
        self._target_ids = None
        self._description = None
        self._compartment_id = None
        self._mime_type = None
        self._time_less_than = None
        self._time_greater_than = None
        self._row_limit = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this GenerateReportDetails.
        The name of the report to be generated


        :return: The display_name of this GenerateReportDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this GenerateReportDetails.
        The name of the report to be generated


        :param display_name: The display_name of this GenerateReportDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def target_ids(self):
        """
        Gets the target_ids of this GenerateReportDetails.
        Array of database target OCIDs.


        :return: The target_ids of this GenerateReportDetails.
        :rtype: list[str]
        """
        return self._target_ids

    @target_ids.setter
    def target_ids(self, target_ids):
        """
        Sets the target_ids of this GenerateReportDetails.
        Array of database target OCIDs.


        :param target_ids: The target_ids of this GenerateReportDetails.
        :type: list[str]
        """
        self._target_ids = target_ids

    @property
    def description(self):
        """
        Gets the description of this GenerateReportDetails.
        The description of the report to be generated


        :return: The description of this GenerateReportDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this GenerateReportDetails.
        The description of the report to be generated


        :param description: The description of this GenerateReportDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this GenerateReportDetails.
        The `OCID`__ of the compartment
        into which the resource should be moved.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this GenerateReportDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this GenerateReportDetails.
        The `OCID`__ of the compartment
        into which the resource should be moved.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this GenerateReportDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def mime_type(self):
        """
        **[Required]** Gets the mime_type of this GenerateReportDetails.
        Specifies the format of report to be excel or pdf

        Allowed values for this property are: "PDF", "XLS"


        :return: The mime_type of this GenerateReportDetails.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """
        Sets the mime_type of this GenerateReportDetails.
        Specifies the format of report to be excel or pdf


        :param mime_type: The mime_type of this GenerateReportDetails.
        :type: str
        """
        allowed_values = ["PDF", "XLS"]
        if not value_allowed_none_or_none_sentinel(mime_type, allowed_values):
            raise ValueError(
                "Invalid value for `mime_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._mime_type = mime_type

    @property
    def time_less_than(self):
        """
        Gets the time_less_than of this GenerateReportDetails.
        Specifies the time before which the data needs to be reported.


        :return: The time_less_than of this GenerateReportDetails.
        :rtype: datetime
        """
        return self._time_less_than

    @time_less_than.setter
    def time_less_than(self, time_less_than):
        """
        Sets the time_less_than of this GenerateReportDetails.
        Specifies the time before which the data needs to be reported.


        :param time_less_than: The time_less_than of this GenerateReportDetails.
        :type: datetime
        """
        self._time_less_than = time_less_than

    @property
    def time_greater_than(self):
        """
        Gets the time_greater_than of this GenerateReportDetails.
        Specifies the time after which the data needs to be reported.


        :return: The time_greater_than of this GenerateReportDetails.
        :rtype: datetime
        """
        return self._time_greater_than

    @time_greater_than.setter
    def time_greater_than(self, time_greater_than):
        """
        Sets the time_greater_than of this GenerateReportDetails.
        Specifies the time after which the data needs to be reported.


        :param time_greater_than: The time_greater_than of this GenerateReportDetails.
        :type: datetime
        """
        self._time_greater_than = time_greater_than

    @property
    def row_limit(self):
        """
        Gets the row_limit of this GenerateReportDetails.
        Specifies the limit on number of rows in report.


        :return: The row_limit of this GenerateReportDetails.
        :rtype: int
        """
        return self._row_limit

    @row_limit.setter
    def row_limit(self, row_limit):
        """
        Sets the row_limit of this GenerateReportDetails.
        Specifies the limit on number of rows in report.


        :param row_limit: The row_limit of this GenerateReportDetails.
        :type: int
        """
        self._row_limit = row_limit

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProductSummary(object):
    """
    Provides details about product rewards and the usage amount.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ProductSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param product_number:
            The value to assign to the product_number property of this ProductSummary.
        :type product_number: str

        :param product_name:
            The value to assign to the product_name property of this ProductSummary.
        :type product_name: str

        :param usage_amount:
            The value to assign to the usage_amount property of this ProductSummary.
        :type usage_amount: float

        :param earned_rewards:
            The value to assign to the earned_rewards property of this ProductSummary.
        :type earned_rewards: float

        :param is_eligible_to_earn_rewards:
            The value to assign to the is_eligible_to_earn_rewards property of this ProductSummary.
        :type is_eligible_to_earn_rewards: bool

        """
        self.swagger_types = {
            'product_number': 'str',
            'product_name': 'str',
            'usage_amount': 'float',
            'earned_rewards': 'float',
            'is_eligible_to_earn_rewards': 'bool'
        }

        self.attribute_map = {
            'product_number': 'productNumber',
            'product_name': 'productName',
            'usage_amount': 'usageAmount',
            'earned_rewards': 'earnedRewards',
            'is_eligible_to_earn_rewards': 'isEligibleToEarnRewards'
        }

        self._product_number = None
        self._product_name = None
        self._usage_amount = None
        self._earned_rewards = None
        self._is_eligible_to_earn_rewards = None

    @property
    def product_number(self):
        """
        Gets the product_number of this ProductSummary.
        The rate card product number.


        :return: The product_number of this ProductSummary.
        :rtype: str
        """
        return self._product_number

    @product_number.setter
    def product_number(self, product_number):
        """
        Sets the product_number of this ProductSummary.
        The rate card product number.


        :param product_number: The product_number of this ProductSummary.
        :type: str
        """
        self._product_number = product_number

    @property
    def product_name(self):
        """
        Gets the product_name of this ProductSummary.
        The rate card product name.


        :return: The product_name of this ProductSummary.
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """
        Sets the product_name of this ProductSummary.
        The rate card product name.


        :param product_name: The product_name of this ProductSummary.
        :type: str
        """
        self._product_name = product_name

    @property
    def usage_amount(self):
        """
        Gets the usage_amount of this ProductSummary.
        The rate card product usage amount.


        :return: The usage_amount of this ProductSummary.
        :rtype: float
        """
        return self._usage_amount

    @usage_amount.setter
    def usage_amount(self, usage_amount):
        """
        Sets the usage_amount of this ProductSummary.
        The rate card product usage amount.


        :param usage_amount: The usage_amount of this ProductSummary.
        :type: float
        """
        self._usage_amount = usage_amount

    @property
    def earned_rewards(self):
        """
        Gets the earned_rewards of this ProductSummary.
        The earned rewards for the product.


        :return: The earned_rewards of this ProductSummary.
        :rtype: float
        """
        return self._earned_rewards

    @earned_rewards.setter
    def earned_rewards(self, earned_rewards):
        """
        Sets the earned_rewards of this ProductSummary.
        The earned rewards for the product.


        :param earned_rewards: The earned_rewards of this ProductSummary.
        :type: float
        """
        self._earned_rewards = earned_rewards

    @property
    def is_eligible_to_earn_rewards(self):
        """
        Gets the is_eligible_to_earn_rewards of this ProductSummary.
        The boolean parameter to indicate if the product is eligible to earn rewards.


        :return: The is_eligible_to_earn_rewards of this ProductSummary.
        :rtype: bool
        """
        return self._is_eligible_to_earn_rewards

    @is_eligible_to_earn_rewards.setter
    def is_eligible_to_earn_rewards(self, is_eligible_to_earn_rewards):
        """
        Sets the is_eligible_to_earn_rewards of this ProductSummary.
        The boolean parameter to indicate if the product is eligible to earn rewards.


        :param is_eligible_to_earn_rewards: The is_eligible_to_earn_rewards of this ProductSummary.
        :type: bool
        """
        self._is_eligible_to_earn_rewards = is_eligible_to_earn_rewards

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IndicatorRelationship(object):
    """
    An relationship name and list of releated entities.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new IndicatorRelationship object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this IndicatorRelationship.
        :type name: str

        :param related_entity:
            The value to assign to the related_entity property of this IndicatorRelationship.
        :type related_entity: oci.threat_intelligence.models.EntityReference

        :param attribution:
            The value to assign to the attribution property of this IndicatorRelationship.
        :type attribution: list[oci.threat_intelligence.models.DataAttribution]

        """
        self.swagger_types = {
            'name': 'str',
            'related_entity': 'EntityReference',
            'attribution': 'list[DataAttribution]'
        }

        self.attribute_map = {
            'name': 'name',
            'related_entity': 'relatedEntity',
            'attribution': 'attribution'
        }

        self._name = None
        self._related_entity = None
        self._attribution = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this IndicatorRelationship.
        The name of the attribute


        :return: The name of this IndicatorRelationship.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IndicatorRelationship.
        The name of the attribute


        :param name: The name of this IndicatorRelationship.
        :type: str
        """
        self._name = name

    @property
    def related_entity(self):
        """
        **[Required]** Gets the related_entity of this IndicatorRelationship.

        :return: The related_entity of this IndicatorRelationship.
        :rtype: oci.threat_intelligence.models.EntityReference
        """
        return self._related_entity

    @related_entity.setter
    def related_entity(self, related_entity):
        """
        Sets the related_entity of this IndicatorRelationship.

        :param related_entity: The related_entity of this IndicatorRelationship.
        :type: oci.threat_intelligence.models.EntityReference
        """
        self._related_entity = related_entity

    @property
    def attribution(self):
        """
        **[Required]** Gets the attribution of this IndicatorRelationship.
        The array of attribution data that support this SourcedRelationship


        :return: The attribution of this IndicatorRelationship.
        :rtype: list[oci.threat_intelligence.models.DataAttribution]
        """
        return self._attribution

    @attribution.setter
    def attribution(self, attribution):
        """
        Sets the attribution of this IndicatorRelationship.
        The array of attribution data that support this SourcedRelationship


        :param attribution: The attribution of this IndicatorRelationship.
        :type: list[oci.threat_intelligence.models.DataAttribution]
        """
        self._attribution = attribution

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplicationDependency(object):
    """
    An Application Dependency resource creates a Vulnerability Audit.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApplicationDependency object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param gav:
            The value to assign to the gav property of this ApplicationDependency.
        :type gav: str

        :param node_id:
            The value to assign to the node_id property of this ApplicationDependency.
        :type node_id: str

        :param application_dependency_node_ids:
            The value to assign to the application_dependency_node_ids property of this ApplicationDependency.
        :type application_dependency_node_ids: list[str]

        """
        self.swagger_types = {
            'gav': 'str',
            'node_id': 'str',
            'application_dependency_node_ids': 'list[str]'
        }

        self.attribute_map = {
            'gav': 'gav',
            'node_id': 'nodeId',
            'application_dependency_node_ids': 'applicationDependencyNodeIds'
        }

        self._gav = None
        self._node_id = None
        self._application_dependency_node_ids = None

    @property
    def gav(self):
        """
        **[Required]** Gets the gav of this ApplicationDependency.
        Unique Group Artifact Version (GAV) identifier (Group:Artifact:Version), e.g. org.graalvm.nativeimage:svm:21.1.0.


        :return: The gav of this ApplicationDependency.
        :rtype: str
        """
        return self._gav

    @gav.setter
    def gav(self, gav):
        """
        Sets the gav of this ApplicationDependency.
        Unique Group Artifact Version (GAV) identifier (Group:Artifact:Version), e.g. org.graalvm.nativeimage:svm:21.1.0.


        :param gav: The gav of this ApplicationDependency.
        :type: str
        """
        self._gav = gav

    @property
    def node_id(self):
        """
        **[Required]** Gets the node_id of this ApplicationDependency.
        Unique identifier of an Application Dependency node, e.g. nodeId1.


        :return: The node_id of this ApplicationDependency.
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """
        Sets the node_id of this ApplicationDependency.
        Unique identifier of an Application Dependency node, e.g. nodeId1.


        :param node_id: The node_id of this ApplicationDependency.
        :type: str
        """
        self._node_id = node_id

    @property
    def application_dependency_node_ids(self):
        """
        **[Required]** Gets the application_dependency_node_ids of this ApplicationDependency.
        List of (Application Dependencies) node identifiers on which this node depends.


        :return: The application_dependency_node_ids of this ApplicationDependency.
        :rtype: list[str]
        """
        return self._application_dependency_node_ids

    @application_dependency_node_ids.setter
    def application_dependency_node_ids(self, application_dependency_node_ids):
        """
        Sets the application_dependency_node_ids of this ApplicationDependency.
        List of (Application Dependencies) node identifiers on which this node depends.


        :param application_dependency_node_ids: The application_dependency_node_ids of this ApplicationDependency.
        :type: list[str]
        """
        self._application_dependency_node_ids = application_dependency_node_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SchemaDriftConfig(object):
    """
    The configuration for handling schema drift in a Source or Target operator.
    """

    #: A constant which can be used with the extra_column_handling property of a SchemaDriftConfig.
    #: This constant has a value of "ALLOW"
    EXTRA_COLUMN_HANDLING_ALLOW = "ALLOW"

    #: A constant which can be used with the extra_column_handling property of a SchemaDriftConfig.
    #: This constant has a value of "NULL_FILLUP"
    EXTRA_COLUMN_HANDLING_NULL_FILLUP = "NULL_FILLUP"

    #: A constant which can be used with the extra_column_handling property of a SchemaDriftConfig.
    #: This constant has a value of "DO_NOT_ALLOW"
    EXTRA_COLUMN_HANDLING_DO_NOT_ALLOW = "DO_NOT_ALLOW"

    #: A constant which can be used with the missing_column_handling property of a SchemaDriftConfig.
    #: This constant has a value of "ALLOW"
    MISSING_COLUMN_HANDLING_ALLOW = "ALLOW"

    #: A constant which can be used with the missing_column_handling property of a SchemaDriftConfig.
    #: This constant has a value of "NULL_SELECT"
    MISSING_COLUMN_HANDLING_NULL_SELECT = "NULL_SELECT"

    #: A constant which can be used with the missing_column_handling property of a SchemaDriftConfig.
    #: This constant has a value of "DO_NOT_ALLOW"
    MISSING_COLUMN_HANDLING_DO_NOT_ALLOW = "DO_NOT_ALLOW"

    #: A constant which can be used with the data_type_change_handling property of a SchemaDriftConfig.
    #: This constant has a value of "ALLOW"
    DATA_TYPE_CHANGE_HANDLING_ALLOW = "ALLOW"

    #: A constant which can be used with the data_type_change_handling property of a SchemaDriftConfig.
    #: This constant has a value of "DO_CAST_IF_POSSIBLE"
    DATA_TYPE_CHANGE_HANDLING_DO_CAST_IF_POSSIBLE = "DO_CAST_IF_POSSIBLE"

    #: A constant which can be used with the data_type_change_handling property of a SchemaDriftConfig.
    #: This constant has a value of "DO_NOT_ALLOW"
    DATA_TYPE_CHANGE_HANDLING_DO_NOT_ALLOW = "DO_NOT_ALLOW"

    def __init__(self, **kwargs):
        """
        Initializes a new SchemaDriftConfig object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param extra_column_handling:
            The value to assign to the extra_column_handling property of this SchemaDriftConfig.
            Allowed values for this property are: "ALLOW", "NULL_FILLUP", "DO_NOT_ALLOW"
        :type extra_column_handling: str

        :param missing_column_handling:
            The value to assign to the missing_column_handling property of this SchemaDriftConfig.
            Allowed values for this property are: "ALLOW", "NULL_SELECT", "DO_NOT_ALLOW"
        :type missing_column_handling: str

        :param data_type_change_handling:
            The value to assign to the data_type_change_handling property of this SchemaDriftConfig.
            Allowed values for this property are: "ALLOW", "DO_CAST_IF_POSSIBLE", "DO_NOT_ALLOW"
        :type data_type_change_handling: str

        :param is_validation_warning_if_allowed:
            The value to assign to the is_validation_warning_if_allowed property of this SchemaDriftConfig.
        :type is_validation_warning_if_allowed: bool

        """
        self.swagger_types = {
            'extra_column_handling': 'str',
            'missing_column_handling': 'str',
            'data_type_change_handling': 'str',
            'is_validation_warning_if_allowed': 'bool'
        }

        self.attribute_map = {
            'extra_column_handling': 'extraColumnHandling',
            'missing_column_handling': 'missingColumnHandling',
            'data_type_change_handling': 'dataTypeChangeHandling',
            'is_validation_warning_if_allowed': 'isValidationWarningIfAllowed'
        }

        self._extra_column_handling = None
        self._missing_column_handling = None
        self._data_type_change_handling = None
        self._is_validation_warning_if_allowed = None

    @property
    def extra_column_handling(self):
        """
        Gets the extra_column_handling of this SchemaDriftConfig.
        The setting for how to handle extra columns/fields.  NULL_FILLUP means that nulls will be loaded into the target for extra columns.

        Allowed values for this property are: "ALLOW", "NULL_FILLUP", "DO_NOT_ALLOW"


        :return: The extra_column_handling of this SchemaDriftConfig.
        :rtype: str
        """
        return self._extra_column_handling

    @extra_column_handling.setter
    def extra_column_handling(self, extra_column_handling):
        """
        Sets the extra_column_handling of this SchemaDriftConfig.
        The setting for how to handle extra columns/fields.  NULL_FILLUP means that nulls will be loaded into the target for extra columns.


        :param extra_column_handling: The extra_column_handling of this SchemaDriftConfig.
        :type: str
        """
        allowed_values = ["ALLOW", "NULL_FILLUP", "DO_NOT_ALLOW"]
        if not value_allowed_none_or_none_sentinel(extra_column_handling, allowed_values):
            raise ValueError(
                "Invalid value for `extra_column_handling`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._extra_column_handling = extra_column_handling

    @property
    def missing_column_handling(self):
        """
        Gets the missing_column_handling of this SchemaDriftConfig.
        The setting for how to handle missing columns/fields.  NULL_SELECT means that null values will be selected from the source for missing columns.

        Allowed values for this property are: "ALLOW", "NULL_SELECT", "DO_NOT_ALLOW"


        :return: The missing_column_handling of this SchemaDriftConfig.
        :rtype: str
        """
        return self._missing_column_handling

    @missing_column_handling.setter
    def missing_column_handling(self, missing_column_handling):
        """
        Sets the missing_column_handling of this SchemaDriftConfig.
        The setting for how to handle missing columns/fields.  NULL_SELECT means that null values will be selected from the source for missing columns.


        :param missing_column_handling: The missing_column_handling of this SchemaDriftConfig.
        :type: str
        """
        allowed_values = ["ALLOW", "NULL_SELECT", "DO_NOT_ALLOW"]
        if not value_allowed_none_or_none_sentinel(missing_column_handling, allowed_values):
            raise ValueError(
                "Invalid value for `missing_column_handling`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._missing_column_handling = missing_column_handling

    @property
    def data_type_change_handling(self):
        """
        Gets the data_type_change_handling of this SchemaDriftConfig.
        The setting for how to handle columns/fields with changed data types.

        Allowed values for this property are: "ALLOW", "DO_CAST_IF_POSSIBLE", "DO_NOT_ALLOW"


        :return: The data_type_change_handling of this SchemaDriftConfig.
        :rtype: str
        """
        return self._data_type_change_handling

    @data_type_change_handling.setter
    def data_type_change_handling(self, data_type_change_handling):
        """
        Sets the data_type_change_handling of this SchemaDriftConfig.
        The setting for how to handle columns/fields with changed data types.


        :param data_type_change_handling: The data_type_change_handling of this SchemaDriftConfig.
        :type: str
        """
        allowed_values = ["ALLOW", "DO_CAST_IF_POSSIBLE", "DO_NOT_ALLOW"]
        if not value_allowed_none_or_none_sentinel(data_type_change_handling, allowed_values):
            raise ValueError(
                "Invalid value for `data_type_change_handling`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._data_type_change_handling = data_type_change_handling

    @property
    def is_validation_warning_if_allowed(self):
        """
        Gets the is_validation_warning_if_allowed of this SchemaDriftConfig.
        If true, display a validation warning for schema changes, even if they are allowed.


        :return: The is_validation_warning_if_allowed of this SchemaDriftConfig.
        :rtype: bool
        """
        return self._is_validation_warning_if_allowed

    @is_validation_warning_if_allowed.setter
    def is_validation_warning_if_allowed(self, is_validation_warning_if_allowed):
        """
        Sets the is_validation_warning_if_allowed of this SchemaDriftConfig.
        If true, display a validation warning for schema changes, even if they are allowed.


        :param is_validation_warning_if_allowed: The is_validation_warning_if_allowed of this SchemaDriftConfig.
        :type: bool
        """
        self._is_validation_warning_if_allowed = is_validation_warning_if_allowed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DocumentFeature(object):
    """
    The type of document analysis.
    """

    #: A constant which can be used with the feature_type property of a DocumentFeature.
    #: This constant has a value of "LANGUAGE_CLASSIFICATION"
    FEATURE_TYPE_LANGUAGE_CLASSIFICATION = "LANGUAGE_CLASSIFICATION"

    #: A constant which can be used with the feature_type property of a DocumentFeature.
    #: This constant has a value of "TEXT_DETECTION"
    FEATURE_TYPE_TEXT_DETECTION = "TEXT_DETECTION"

    #: A constant which can be used with the feature_type property of a DocumentFeature.
    #: This constant has a value of "TABLE_DETECTION"
    FEATURE_TYPE_TABLE_DETECTION = "TABLE_DETECTION"

    #: A constant which can be used with the feature_type property of a DocumentFeature.
    #: This constant has a value of "KEY_VALUE_DETECTION"
    FEATURE_TYPE_KEY_VALUE_DETECTION = "KEY_VALUE_DETECTION"

    #: A constant which can be used with the feature_type property of a DocumentFeature.
    #: This constant has a value of "DOCUMENT_CLASSIFICATION"
    FEATURE_TYPE_DOCUMENT_CLASSIFICATION = "DOCUMENT_CLASSIFICATION"

    def __init__(self, **kwargs):
        """
        Initializes a new DocumentFeature object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.ai_vision.models.DocumentTableDetectionFeature`
        * :class:`~oci.ai_vision.models.DocumentKeyValueDetectionFeature`
        * :class:`~oci.ai_vision.models.DocumentClassificationFeature`
        * :class:`~oci.ai_vision.models.DocumentTextDetectionFeature`
        * :class:`~oci.ai_vision.models.DocumentLanguageClassificationFeature`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param feature_type:
            The value to assign to the feature_type property of this DocumentFeature.
            Allowed values for this property are: "LANGUAGE_CLASSIFICATION", "TEXT_DETECTION", "TABLE_DETECTION", "KEY_VALUE_DETECTION", "DOCUMENT_CLASSIFICATION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type feature_type: str

        """
        self.swagger_types = {
            'feature_type': 'str'
        }

        self.attribute_map = {
            'feature_type': 'featureType'
        }

        self._feature_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['featureType']

        if type == 'TABLE_DETECTION':
            return 'DocumentTableDetectionFeature'

        if type == 'KEY_VALUE_DETECTION':
            return 'DocumentKeyValueDetectionFeature'

        if type == 'DOCUMENT_CLASSIFICATION':
            return 'DocumentClassificationFeature'

        if type == 'TEXT_DETECTION':
            return 'DocumentTextDetectionFeature'

        if type == 'LANGUAGE_CLASSIFICATION':
            return 'DocumentLanguageClassificationFeature'
        else:
            return 'DocumentFeature'

    @property
    def feature_type(self):
        """
        **[Required]** Gets the feature_type of this DocumentFeature.
        The type of document analysis requested.
        The allowed values are:
        - `LANGUAGE_CLASSIFICATION`: Detect the language.
        - `TEXT_DETECTION`: Recognize text.
        - `TABLE_DETECTION`: Detect and extract data in tables.
        - `KEY_VALUE_DETECTION`: Extract form fields.
        - `DOCUMENT_CLASSIFICATION`: Identify the type of document.

        Allowed values for this property are: "LANGUAGE_CLASSIFICATION", "TEXT_DETECTION", "TABLE_DETECTION", "KEY_VALUE_DETECTION", "DOCUMENT_CLASSIFICATION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The feature_type of this DocumentFeature.
        :rtype: str
        """
        return self._feature_type

    @feature_type.setter
    def feature_type(self, feature_type):
        """
        Sets the feature_type of this DocumentFeature.
        The type of document analysis requested.
        The allowed values are:
        - `LANGUAGE_CLASSIFICATION`: Detect the language.
        - `TEXT_DETECTION`: Recognize text.
        - `TABLE_DETECTION`: Detect and extract data in tables.
        - `KEY_VALUE_DETECTION`: Extract form fields.
        - `DOCUMENT_CLASSIFICATION`: Identify the type of document.


        :param feature_type: The feature_type of this DocumentFeature.
        :type: str
        """
        allowed_values = ["LANGUAGE_CLASSIFICATION", "TEXT_DETECTION", "TABLE_DETECTION", "KEY_VALUE_DETECTION", "DOCUMENT_CLASSIFICATION"]
        if not value_allowed_none_or_none_sentinel(feature_type, allowed_values):
            feature_type = 'UNKNOWN_ENUM_VALUE'
        self._feature_type = feature_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TopProcessesUsageTrendAggregation(object):
    """
    Usage data per host top process
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TopProcessesUsageTrendAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param command:
            The value to assign to the command property of this TopProcessesUsageTrendAggregation.
        :type command: str

        :param usage_data:
            The value to assign to the usage_data property of this TopProcessesUsageTrendAggregation.
        :type usage_data: list[oci.opsi.models.TopProcessesUsageTrend]

        """
        self.swagger_types = {
            'command': 'str',
            'usage_data': 'list[TopProcessesUsageTrend]'
        }

        self.attribute_map = {
            'command': 'command',
            'usage_data': 'usageData'
        }

        self._command = None
        self._usage_data = None

    @property
    def command(self):
        """
        **[Required]** Gets the command of this TopProcessesUsageTrendAggregation.
        Command line and arguments used to launch process


        :return: The command of this TopProcessesUsageTrendAggregation.
        :rtype: str
        """
        return self._command

    @command.setter
    def command(self, command):
        """
        Sets the command of this TopProcessesUsageTrendAggregation.
        Command line and arguments used to launch process


        :param command: The command of this TopProcessesUsageTrendAggregation.
        :type: str
        """
        self._command = command

    @property
    def usage_data(self):
        """
        **[Required]** Gets the usage_data of this TopProcessesUsageTrendAggregation.
        List of usage data samples for a top process


        :return: The usage_data of this TopProcessesUsageTrendAggregation.
        :rtype: list[oci.opsi.models.TopProcessesUsageTrend]
        """
        return self._usage_data

    @usage_data.setter
    def usage_data(self, usage_data):
        """
        Sets the usage_data of this TopProcessesUsageTrendAggregation.
        List of usage data samples for a top process


        :param usage_data: The usage_data of this TopProcessesUsageTrendAggregation.
        :type: list[oci.opsi.models.TopProcessesUsageTrend]
        """
        self._usage_data = usage_data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .build_pipeline_stage_run_progress import BuildPipelineStageRunProgress
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TriggerDeploymentPipelineStageRunProgress(BuildPipelineStageRunProgress):
    """
    Specifies Trigger Deployment Pipleline stage specific run details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TriggerDeploymentPipelineStageRunProgress object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.TriggerDeploymentPipelineStageRunProgress.build_pipeline_stage_type` attribute
        of this class is ``TRIGGER_DEPLOYMENT_PIPELINE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stage_display_name:
            The value to assign to the stage_display_name property of this TriggerDeploymentPipelineStageRunProgress.
        :type stage_display_name: str

        :param build_pipeline_stage_type:
            The value to assign to the build_pipeline_stage_type property of this TriggerDeploymentPipelineStageRunProgress.
        :type build_pipeline_stage_type: str

        :param build_pipeline_stage_id:
            The value to assign to the build_pipeline_stage_id property of this TriggerDeploymentPipelineStageRunProgress.
        :type build_pipeline_stage_id: str

        :param time_started:
            The value to assign to the time_started property of this TriggerDeploymentPipelineStageRunProgress.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this TriggerDeploymentPipelineStageRunProgress.
        :type time_finished: datetime

        :param status:
            The value to assign to the status property of this TriggerDeploymentPipelineStageRunProgress.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED"
        :type status: str

        :param build_pipeline_stage_predecessors:
            The value to assign to the build_pipeline_stage_predecessors property of this TriggerDeploymentPipelineStageRunProgress.
        :type build_pipeline_stage_predecessors: oci.devops.models.BuildPipelineStagePredecessorCollection

        :param exported_variables:
            The value to assign to the exported_variables property of this TriggerDeploymentPipelineStageRunProgress.
        :type exported_variables: oci.devops.models.ExportedVariableCollection

        :param artifact_override_parameters:
            The value to assign to the artifact_override_parameters property of this TriggerDeploymentPipelineStageRunProgress.
        :type artifact_override_parameters: oci.devops.models.DeployArtifactOverrideArgumentCollection

        :param deployment_id:
            The value to assign to the deployment_id property of this TriggerDeploymentPipelineStageRunProgress.
        :type deployment_id: str

        """
        self.swagger_types = {
            'stage_display_name': 'str',
            'build_pipeline_stage_type': 'str',
            'build_pipeline_stage_id': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'status': 'str',
            'build_pipeline_stage_predecessors': 'BuildPipelineStagePredecessorCollection',
            'exported_variables': 'ExportedVariableCollection',
            'artifact_override_parameters': 'DeployArtifactOverrideArgumentCollection',
            'deployment_id': 'str'
        }

        self.attribute_map = {
            'stage_display_name': 'stageDisplayName',
            'build_pipeline_stage_type': 'buildPipelineStageType',
            'build_pipeline_stage_id': 'buildPipelineStageId',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'status': 'status',
            'build_pipeline_stage_predecessors': 'buildPipelineStagePredecessors',
            'exported_variables': 'exportedVariables',
            'artifact_override_parameters': 'artifactOverrideParameters',
            'deployment_id': 'deploymentId'
        }

        self._stage_display_name = None
        self._build_pipeline_stage_type = None
        self._build_pipeline_stage_id = None
        self._time_started = None
        self._time_finished = None
        self._status = None
        self._build_pipeline_stage_predecessors = None
        self._exported_variables = None
        self._artifact_override_parameters = None
        self._deployment_id = None
        self._build_pipeline_stage_type = 'TRIGGER_DEPLOYMENT_PIPELINE'

    @property
    def exported_variables(self):
        """
        Gets the exported_variables of this TriggerDeploymentPipelineStageRunProgress.

        :return: The exported_variables of this TriggerDeploymentPipelineStageRunProgress.
        :rtype: oci.devops.models.ExportedVariableCollection
        """
        return self._exported_variables

    @exported_variables.setter
    def exported_variables(self, exported_variables):
        """
        Sets the exported_variables of this TriggerDeploymentPipelineStageRunProgress.

        :param exported_variables: The exported_variables of this TriggerDeploymentPipelineStageRunProgress.
        :type: oci.devops.models.ExportedVariableCollection
        """
        self._exported_variables = exported_variables

    @property
    def artifact_override_parameters(self):
        """
        Gets the artifact_override_parameters of this TriggerDeploymentPipelineStageRunProgress.

        :return: The artifact_override_parameters of this TriggerDeploymentPipelineStageRunProgress.
        :rtype: oci.devops.models.DeployArtifactOverrideArgumentCollection
        """
        return self._artifact_override_parameters

    @artifact_override_parameters.setter
    def artifact_override_parameters(self, artifact_override_parameters):
        """
        Sets the artifact_override_parameters of this TriggerDeploymentPipelineStageRunProgress.

        :param artifact_override_parameters: The artifact_override_parameters of this TriggerDeploymentPipelineStageRunProgress.
        :type: oci.devops.models.DeployArtifactOverrideArgumentCollection
        """
        self._artifact_override_parameters = artifact_override_parameters

    @property
    def deployment_id(self):
        """
        Gets the deployment_id of this TriggerDeploymentPipelineStageRunProgress.
        Identifier of the deployment triggered.


        :return: The deployment_id of this TriggerDeploymentPipelineStageRunProgress.
        :rtype: str
        """
        return self._deployment_id

    @deployment_id.setter
    def deployment_id(self, deployment_id):
        """
        Sets the deployment_id of this TriggerDeploymentPipelineStageRunProgress.
        Identifier of the deployment triggered.


        :param deployment_id: The deployment_id of this TriggerDeploymentPipelineStageRunProgress.
        :type: str
        """
        self._deployment_id = deployment_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
